import { ElasticsearchServiceClient } from "./ElasticsearchServiceClient";
import { AddTagsInput } from "./types/AddTagsInput";
import { AddTagsOutput } from "./types/AddTagsOutput";
import { CancelElasticsearchServiceSoftwareUpdateInput } from "./types/CancelElasticsearchServiceSoftwareUpdateInput";
import { CancelElasticsearchServiceSoftwareUpdateOutput } from "./types/CancelElasticsearchServiceSoftwareUpdateOutput";
import { CreateElasticsearchDomainInput } from "./types/CreateElasticsearchDomainInput";
import { CreateElasticsearchDomainOutput } from "./types/CreateElasticsearchDomainOutput";
import { DeleteElasticsearchDomainInput } from "./types/DeleteElasticsearchDomainInput";
import { DeleteElasticsearchDomainOutput } from "./types/DeleteElasticsearchDomainOutput";
import { DeleteElasticsearchServiceRoleInput } from "./types/DeleteElasticsearchServiceRoleInput";
import { DeleteElasticsearchServiceRoleOutput } from "./types/DeleteElasticsearchServiceRoleOutput";
import { DescribeElasticsearchDomainConfigInput } from "./types/DescribeElasticsearchDomainConfigInput";
import { DescribeElasticsearchDomainConfigOutput } from "./types/DescribeElasticsearchDomainConfigOutput";
import { DescribeElasticsearchDomainInput } from "./types/DescribeElasticsearchDomainInput";
import { DescribeElasticsearchDomainOutput } from "./types/DescribeElasticsearchDomainOutput";
import { DescribeElasticsearchDomainsInput } from "./types/DescribeElasticsearchDomainsInput";
import { DescribeElasticsearchDomainsOutput } from "./types/DescribeElasticsearchDomainsOutput";
import { DescribeElasticsearchInstanceTypeLimitsInput } from "./types/DescribeElasticsearchInstanceTypeLimitsInput";
import { DescribeElasticsearchInstanceTypeLimitsOutput } from "./types/DescribeElasticsearchInstanceTypeLimitsOutput";
import { DescribeReservedElasticsearchInstanceOfferingsInput } from "./types/DescribeReservedElasticsearchInstanceOfferingsInput";
import { DescribeReservedElasticsearchInstanceOfferingsOutput } from "./types/DescribeReservedElasticsearchInstanceOfferingsOutput";
import { DescribeReservedElasticsearchInstancesInput } from "./types/DescribeReservedElasticsearchInstancesInput";
import { DescribeReservedElasticsearchInstancesOutput } from "./types/DescribeReservedElasticsearchInstancesOutput";
import { GetCompatibleElasticsearchVersionsInput } from "./types/GetCompatibleElasticsearchVersionsInput";
import { GetCompatibleElasticsearchVersionsOutput } from "./types/GetCompatibleElasticsearchVersionsOutput";
import { GetUpgradeHistoryInput } from "./types/GetUpgradeHistoryInput";
import { GetUpgradeHistoryOutput } from "./types/GetUpgradeHistoryOutput";
import { GetUpgradeStatusInput } from "./types/GetUpgradeStatusInput";
import { GetUpgradeStatusOutput } from "./types/GetUpgradeStatusOutput";
import { ListDomainNamesInput } from "./types/ListDomainNamesInput";
import { ListDomainNamesOutput } from "./types/ListDomainNamesOutput";
import { ListElasticsearchInstanceTypesInput } from "./types/ListElasticsearchInstanceTypesInput";
import { ListElasticsearchInstanceTypesOutput } from "./types/ListElasticsearchInstanceTypesOutput";
import { ListElasticsearchVersionsInput } from "./types/ListElasticsearchVersionsInput";
import { ListElasticsearchVersionsOutput } from "./types/ListElasticsearchVersionsOutput";
import { ListTagsInput } from "./types/ListTagsInput";
import { ListTagsOutput } from "./types/ListTagsOutput";
import { PurchaseReservedElasticsearchInstanceOfferingInput } from "./types/PurchaseReservedElasticsearchInstanceOfferingInput";
import { PurchaseReservedElasticsearchInstanceOfferingOutput } from "./types/PurchaseReservedElasticsearchInstanceOfferingOutput";
import { RemoveTagsInput } from "./types/RemoveTagsInput";
import { RemoveTagsOutput } from "./types/RemoveTagsOutput";
import { StartElasticsearchServiceSoftwareUpdateInput } from "./types/StartElasticsearchServiceSoftwareUpdateInput";
import { StartElasticsearchServiceSoftwareUpdateOutput } from "./types/StartElasticsearchServiceSoftwareUpdateOutput";
import { UpdateElasticsearchDomainConfigInput } from "./types/UpdateElasticsearchDomainConfigInput";
import { UpdateElasticsearchDomainConfigOutput } from "./types/UpdateElasticsearchDomainConfigOutput";
import { UpgradeElasticsearchDomainInput } from "./types/UpgradeElasticsearchDomainInput";
import { UpgradeElasticsearchDomainOutput } from "./types/UpgradeElasticsearchDomainOutput";
export declare class ElasticsearchService extends ElasticsearchServiceClient {
    /**
     * <p>Attaches tags to an existing Elasticsearch domain. Tags are a set of case-sensitive key value pairs. An Elasticsearch domain may have up to 10 tags. See <a href="http://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-managedomains.html#es-managedomains-awsresorcetagging" target="_blank"> Tagging Amazon Elasticsearch Service Domains for more information.</a></p>
     *
     * This operation may fail with one of the following errors:
     *   - {BaseException} <p>An error occurred while processing the request.</p>
     *   - {LimitExceededException} <p>An exception for trying to create more than allowed resources or sub-resources. Gives http status code of 409.</p>
     *   - {ValidationException} <p>An exception for missing / invalid input fields. Gives http status code of 400.</p>
     *   - {InternalException} <p>The request processing has failed because of an unknown error, exception or failure (the failure is internal to the service) . Gives http status code of 500.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    addTags(args: AddTagsInput): Promise<AddTagsOutput>;
    addTags(args: AddTagsInput, cb: (err: any, data?: AddTagsOutput) => void): void;
    /**
     * <p>Cancels a scheduled service software update for an Amazon ES domain. You can only perform this operation before the <code>AutomatedUpdateDate</code> and when the <code>UpdateStatus</code> is in the <code>PENDING_UPDATE</code> state.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {BaseException} <p>An error occurred while processing the request.</p>
     *   - {InternalException} <p>The request processing has failed because of an unknown error, exception or failure (the failure is internal to the service) . Gives http status code of 500.</p>
     *   - {ResourceNotFoundException} <p>An exception for accessing or deleting a resource that does not exist. Gives http status code of 400.</p>
     *   - {ValidationException} <p>An exception for missing / invalid input fields. Gives http status code of 400.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    cancelElasticsearchServiceSoftwareUpdate(args: CancelElasticsearchServiceSoftwareUpdateInput): Promise<CancelElasticsearchServiceSoftwareUpdateOutput>;
    cancelElasticsearchServiceSoftwareUpdate(args: CancelElasticsearchServiceSoftwareUpdateInput, cb: (err: any, data?: CancelElasticsearchServiceSoftwareUpdateOutput) => void): void;
    /**
     * <p>Creates a new Elasticsearch domain. For more information, see <a href="http://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-createupdatedomains.html#es-createdomains" target="_blank">Creating Elasticsearch Domains</a> in the <i>Amazon Elasticsearch Service Developer Guide</i>.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {BaseException} <p>An error occurred while processing the request.</p>
     *   - {DisabledOperationException} <p>An error occured because the client wanted to access a not supported operation. Gives http status code of 409.</p>
     *   - {InternalException} <p>The request processing has failed because of an unknown error, exception or failure (the failure is internal to the service) . Gives http status code of 500.</p>
     *   - {InvalidTypeException} <p>An exception for trying to create or access sub-resource that is either invalid or not supported. Gives http status code of 409.</p>
     *   - {LimitExceededException} <p>An exception for trying to create more than allowed resources or sub-resources. Gives http status code of 409.</p>
     *   - {ResourceAlreadyExistsException} <p>An exception for creating a resource that already exists. Gives http status code of 400.</p>
     *   - {ValidationException} <p>An exception for missing / invalid input fields. Gives http status code of 400.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    createElasticsearchDomain(args: CreateElasticsearchDomainInput): Promise<CreateElasticsearchDomainOutput>;
    createElasticsearchDomain(args: CreateElasticsearchDomainInput, cb: (err: any, data?: CreateElasticsearchDomainOutput) => void): void;
    /**
     * <p>Permanently deletes the specified Elasticsearch domain and all of its data. Once a domain is deleted, it cannot be recovered.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {BaseException} <p>An error occurred while processing the request.</p>
     *   - {InternalException} <p>The request processing has failed because of an unknown error, exception or failure (the failure is internal to the service) . Gives http status code of 500.</p>
     *   - {ResourceNotFoundException} <p>An exception for accessing or deleting a resource that does not exist. Gives http status code of 400.</p>
     *   - {ValidationException} <p>An exception for missing / invalid input fields. Gives http status code of 400.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    deleteElasticsearchDomain(args: DeleteElasticsearchDomainInput): Promise<DeleteElasticsearchDomainOutput>;
    deleteElasticsearchDomain(args: DeleteElasticsearchDomainInput, cb: (err: any, data?: DeleteElasticsearchDomainOutput) => void): void;
    /**
     * <p>Deletes the service-linked role that Elasticsearch Service uses to manage and maintain VPC domains. Role deletion will fail if any existing VPC domains use the role. You must delete any such Elasticsearch domains before deleting the role. See <a href="http://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-vpc.html#es-enabling-slr" target="_blank">Deleting Elasticsearch Service Role</a> in <i>VPC Endpoints for Amazon Elasticsearch Service Domains</i>.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {BaseException} <p>An error occurred while processing the request.</p>
     *   - {InternalException} <p>The request processing has failed because of an unknown error, exception or failure (the failure is internal to the service) . Gives http status code of 500.</p>
     *   - {ValidationException} <p>An exception for missing / invalid input fields. Gives http status code of 400.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    deleteElasticsearchServiceRole(args: DeleteElasticsearchServiceRoleInput): Promise<DeleteElasticsearchServiceRoleOutput>;
    deleteElasticsearchServiceRole(args: DeleteElasticsearchServiceRoleInput, cb: (err: any, data?: DeleteElasticsearchServiceRoleOutput) => void): void;
    /**
     * <p>Returns domain configuration information about the specified Elasticsearch domain, including the domain ID, domain endpoint, and domain ARN.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {BaseException} <p>An error occurred while processing the request.</p>
     *   - {InternalException} <p>The request processing has failed because of an unknown error, exception or failure (the failure is internal to the service) . Gives http status code of 500.</p>
     *   - {ResourceNotFoundException} <p>An exception for accessing or deleting a resource that does not exist. Gives http status code of 400.</p>
     *   - {ValidationException} <p>An exception for missing / invalid input fields. Gives http status code of 400.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    describeElasticsearchDomain(args: DescribeElasticsearchDomainInput): Promise<DescribeElasticsearchDomainOutput>;
    describeElasticsearchDomain(args: DescribeElasticsearchDomainInput, cb: (err: any, data?: DescribeElasticsearchDomainOutput) => void): void;
    /**
     * <p>Provides cluster configuration information about the specified Elasticsearch domain, such as the state, creation date, update version, and update date for cluster options.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {BaseException} <p>An error occurred while processing the request.</p>
     *   - {InternalException} <p>The request processing has failed because of an unknown error, exception or failure (the failure is internal to the service) . Gives http status code of 500.</p>
     *   - {ResourceNotFoundException} <p>An exception for accessing or deleting a resource that does not exist. Gives http status code of 400.</p>
     *   - {ValidationException} <p>An exception for missing / invalid input fields. Gives http status code of 400.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    describeElasticsearchDomainConfig(args: DescribeElasticsearchDomainConfigInput): Promise<DescribeElasticsearchDomainConfigOutput>;
    describeElasticsearchDomainConfig(args: DescribeElasticsearchDomainConfigInput, cb: (err: any, data?: DescribeElasticsearchDomainConfigOutput) => void): void;
    /**
     * <p>Returns domain configuration information about the specified Elasticsearch domains, including the domain ID, domain endpoint, and domain ARN.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {BaseException} <p>An error occurred while processing the request.</p>
     *   - {InternalException} <p>The request processing has failed because of an unknown error, exception or failure (the failure is internal to the service) . Gives http status code of 500.</p>
     *   - {ValidationException} <p>An exception for missing / invalid input fields. Gives http status code of 400.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    describeElasticsearchDomains(args: DescribeElasticsearchDomainsInput): Promise<DescribeElasticsearchDomainsOutput>;
    describeElasticsearchDomains(args: DescribeElasticsearchDomainsInput, cb: (err: any, data?: DescribeElasticsearchDomainsOutput) => void): void;
    /**
     * <p> Describe Elasticsearch Limits for a given InstanceType and ElasticsearchVersion. When modifying existing Domain, specify the <code> <a>DomainName</a> </code> to know what Limits are supported for modifying. </p>
     *
     * This operation may fail with one of the following errors:
     *   - {BaseException} <p>An error occurred while processing the request.</p>
     *   - {InternalException} <p>The request processing has failed because of an unknown error, exception or failure (the failure is internal to the service) . Gives http status code of 500.</p>
     *   - {InvalidTypeException} <p>An exception for trying to create or access sub-resource that is either invalid or not supported. Gives http status code of 409.</p>
     *   - {LimitExceededException} <p>An exception for trying to create more than allowed resources or sub-resources. Gives http status code of 409.</p>
     *   - {ResourceNotFoundException} <p>An exception for accessing or deleting a resource that does not exist. Gives http status code of 400.</p>
     *   - {ValidationException} <p>An exception for missing / invalid input fields. Gives http status code of 400.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    describeElasticsearchInstanceTypeLimits(args: DescribeElasticsearchInstanceTypeLimitsInput): Promise<DescribeElasticsearchInstanceTypeLimitsOutput>;
    describeElasticsearchInstanceTypeLimits(args: DescribeElasticsearchInstanceTypeLimitsInput, cb: (err: any, data?: DescribeElasticsearchInstanceTypeLimitsOutput) => void): void;
    /**
     * <p>Lists available reserved Elasticsearch instance offerings.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ResourceNotFoundException} <p>An exception for accessing or deleting a resource that does not exist. Gives http status code of 400.</p>
     *   - {ValidationException} <p>An exception for missing / invalid input fields. Gives http status code of 400.</p>
     *   - {DisabledOperationException} <p>An error occured because the client wanted to access a not supported operation. Gives http status code of 409.</p>
     *   - {InternalException} <p>The request processing has failed because of an unknown error, exception or failure (the failure is internal to the service) . Gives http status code of 500.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    describeReservedElasticsearchInstanceOfferings(args: DescribeReservedElasticsearchInstanceOfferingsInput): Promise<DescribeReservedElasticsearchInstanceOfferingsOutput>;
    describeReservedElasticsearchInstanceOfferings(args: DescribeReservedElasticsearchInstanceOfferingsInput, cb: (err: any, data?: DescribeReservedElasticsearchInstanceOfferingsOutput) => void): void;
    /**
     * <p>Returns information about reserved Elasticsearch instances for this account.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ResourceNotFoundException} <p>An exception for accessing or deleting a resource that does not exist. Gives http status code of 400.</p>
     *   - {InternalException} <p>The request processing has failed because of an unknown error, exception or failure (the failure is internal to the service) . Gives http status code of 500.</p>
     *   - {ValidationException} <p>An exception for missing / invalid input fields. Gives http status code of 400.</p>
     *   - {DisabledOperationException} <p>An error occured because the client wanted to access a not supported operation. Gives http status code of 409.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    describeReservedElasticsearchInstances(args: DescribeReservedElasticsearchInstancesInput): Promise<DescribeReservedElasticsearchInstancesOutput>;
    describeReservedElasticsearchInstances(args: DescribeReservedElasticsearchInstancesInput, cb: (err: any, data?: DescribeReservedElasticsearchInstancesOutput) => void): void;
    /**
     * <p> Returns a list of upgrade compatible Elastisearch versions. You can optionally pass a <code> <a>DomainName</a> </code> to get all upgrade compatible Elasticsearch versions for that specific domain. </p>
     *
     * This operation may fail with one of the following errors:
     *   - {BaseException} <p>An error occurred while processing the request.</p>
     *   - {ResourceNotFoundException} <p>An exception for accessing or deleting a resource that does not exist. Gives http status code of 400.</p>
     *   - {DisabledOperationException} <p>An error occured because the client wanted to access a not supported operation. Gives http status code of 409.</p>
     *   - {ValidationException} <p>An exception for missing / invalid input fields. Gives http status code of 400.</p>
     *   - {InternalException} <p>The request processing has failed because of an unknown error, exception or failure (the failure is internal to the service) . Gives http status code of 500.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    getCompatibleElasticsearchVersions(args: GetCompatibleElasticsearchVersionsInput): Promise<GetCompatibleElasticsearchVersionsOutput>;
    getCompatibleElasticsearchVersions(args: GetCompatibleElasticsearchVersionsInput, cb: (err: any, data?: GetCompatibleElasticsearchVersionsOutput) => void): void;
    /**
     * <p>Retrieves the complete history of the last 10 upgrades that were performed on the domain.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {BaseException} <p>An error occurred while processing the request.</p>
     *   - {ResourceNotFoundException} <p>An exception for accessing or deleting a resource that does not exist. Gives http status code of 400.</p>
     *   - {DisabledOperationException} <p>An error occured because the client wanted to access a not supported operation. Gives http status code of 409.</p>
     *   - {ValidationException} <p>An exception for missing / invalid input fields. Gives http status code of 400.</p>
     *   - {InternalException} <p>The request processing has failed because of an unknown error, exception or failure (the failure is internal to the service) . Gives http status code of 500.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    getUpgradeHistory(args: GetUpgradeHistoryInput): Promise<GetUpgradeHistoryOutput>;
    getUpgradeHistory(args: GetUpgradeHistoryInput, cb: (err: any, data?: GetUpgradeHistoryOutput) => void): void;
    /**
     * <p>Retrieves the latest status of the last upgrade or upgrade eligibility check that was performed on the domain.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {BaseException} <p>An error occurred while processing the request.</p>
     *   - {ResourceNotFoundException} <p>An exception for accessing or deleting a resource that does not exist. Gives http status code of 400.</p>
     *   - {DisabledOperationException} <p>An error occured because the client wanted to access a not supported operation. Gives http status code of 409.</p>
     *   - {ValidationException} <p>An exception for missing / invalid input fields. Gives http status code of 400.</p>
     *   - {InternalException} <p>The request processing has failed because of an unknown error, exception or failure (the failure is internal to the service) . Gives http status code of 500.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    getUpgradeStatus(args: GetUpgradeStatusInput): Promise<GetUpgradeStatusOutput>;
    getUpgradeStatus(args: GetUpgradeStatusInput, cb: (err: any, data?: GetUpgradeStatusOutput) => void): void;
    /**
     * <p>Returns the name of all Elasticsearch domains owned by the current user's account. </p>
     *
     * This operation may fail with one of the following errors:
     *   - {BaseException} <p>An error occurred while processing the request.</p>
     *   - {ValidationException} <p>An exception for missing / invalid input fields. Gives http status code of 400.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    listDomainNames(args: ListDomainNamesInput): Promise<ListDomainNamesOutput>;
    listDomainNames(args: ListDomainNamesInput, cb: (err: any, data?: ListDomainNamesOutput) => void): void;
    /**
     * <p>List all Elasticsearch instance types that are supported for given ElasticsearchVersion</p>
     *
     * This operation may fail with one of the following errors:
     *   - {BaseException} <p>An error occurred while processing the request.</p>
     *   - {InternalException} <p>The request processing has failed because of an unknown error, exception or failure (the failure is internal to the service) . Gives http status code of 500.</p>
     *   - {ResourceNotFoundException} <p>An exception for accessing or deleting a resource that does not exist. Gives http status code of 400.</p>
     *   - {ValidationException} <p>An exception for missing / invalid input fields. Gives http status code of 400.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    listElasticsearchInstanceTypes(args: ListElasticsearchInstanceTypesInput): Promise<ListElasticsearchInstanceTypesOutput>;
    listElasticsearchInstanceTypes(args: ListElasticsearchInstanceTypesInput, cb: (err: any, data?: ListElasticsearchInstanceTypesOutput) => void): void;
    /**
     * <p>List all supported Elasticsearch versions</p>
     *
     * This operation may fail with one of the following errors:
     *   - {BaseException} <p>An error occurred while processing the request.</p>
     *   - {InternalException} <p>The request processing has failed because of an unknown error, exception or failure (the failure is internal to the service) . Gives http status code of 500.</p>
     *   - {ResourceNotFoundException} <p>An exception for accessing or deleting a resource that does not exist. Gives http status code of 400.</p>
     *   - {ValidationException} <p>An exception for missing / invalid input fields. Gives http status code of 400.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    listElasticsearchVersions(args: ListElasticsearchVersionsInput): Promise<ListElasticsearchVersionsOutput>;
    listElasticsearchVersions(args: ListElasticsearchVersionsInput, cb: (err: any, data?: ListElasticsearchVersionsOutput) => void): void;
    /**
     * <p>Returns all tags for the given Elasticsearch domain.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {BaseException} <p>An error occurred while processing the request.</p>
     *   - {ResourceNotFoundException} <p>An exception for accessing or deleting a resource that does not exist. Gives http status code of 400.</p>
     *   - {ValidationException} <p>An exception for missing / invalid input fields. Gives http status code of 400.</p>
     *   - {InternalException} <p>The request processing has failed because of an unknown error, exception or failure (the failure is internal to the service) . Gives http status code of 500.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    listTags(args: ListTagsInput): Promise<ListTagsOutput>;
    listTags(args: ListTagsInput, cb: (err: any, data?: ListTagsOutput) => void): void;
    /**
     * <p>Allows you to purchase reserved Elasticsearch instances.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {ResourceNotFoundException} <p>An exception for accessing or deleting a resource that does not exist. Gives http status code of 400.</p>
     *   - {ResourceAlreadyExistsException} <p>An exception for creating a resource that already exists. Gives http status code of 400.</p>
     *   - {LimitExceededException} <p>An exception for trying to create more than allowed resources or sub-resources. Gives http status code of 409.</p>
     *   - {DisabledOperationException} <p>An error occured because the client wanted to access a not supported operation. Gives http status code of 409.</p>
     *   - {ValidationException} <p>An exception for missing / invalid input fields. Gives http status code of 400.</p>
     *   - {InternalException} <p>The request processing has failed because of an unknown error, exception or failure (the failure is internal to the service) . Gives http status code of 500.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    purchaseReservedElasticsearchInstanceOffering(args: PurchaseReservedElasticsearchInstanceOfferingInput): Promise<PurchaseReservedElasticsearchInstanceOfferingOutput>;
    purchaseReservedElasticsearchInstanceOffering(args: PurchaseReservedElasticsearchInstanceOfferingInput, cb: (err: any, data?: PurchaseReservedElasticsearchInstanceOfferingOutput) => void): void;
    /**
     * <p>Removes the specified set of tags from the specified Elasticsearch domain.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {BaseException} <p>An error occurred while processing the request.</p>
     *   - {ValidationException} <p>An exception for missing / invalid input fields. Gives http status code of 400.</p>
     *   - {InternalException} <p>The request processing has failed because of an unknown error, exception or failure (the failure is internal to the service) . Gives http status code of 500.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    removeTags(args: RemoveTagsInput): Promise<RemoveTagsOutput>;
    removeTags(args: RemoveTagsInput, cb: (err: any, data?: RemoveTagsOutput) => void): void;
    /**
     * <p>Schedules a service software update for an Amazon ES domain.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {BaseException} <p>An error occurred while processing the request.</p>
     *   - {InternalException} <p>The request processing has failed because of an unknown error, exception or failure (the failure is internal to the service) . Gives http status code of 500.</p>
     *   - {ResourceNotFoundException} <p>An exception for accessing or deleting a resource that does not exist. Gives http status code of 400.</p>
     *   - {ValidationException} <p>An exception for missing / invalid input fields. Gives http status code of 400.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    startElasticsearchServiceSoftwareUpdate(args: StartElasticsearchServiceSoftwareUpdateInput): Promise<StartElasticsearchServiceSoftwareUpdateOutput>;
    startElasticsearchServiceSoftwareUpdate(args: StartElasticsearchServiceSoftwareUpdateInput, cb: (err: any, data?: StartElasticsearchServiceSoftwareUpdateOutput) => void): void;
    /**
     * <p>Modifies the cluster configuration of the specified Elasticsearch domain, setting as setting the instance type and the number of instances. </p>
     *
     * This operation may fail with one of the following errors:
     *   - {BaseException} <p>An error occurred while processing the request.</p>
     *   - {InternalException} <p>The request processing has failed because of an unknown error, exception or failure (the failure is internal to the service) . Gives http status code of 500.</p>
     *   - {InvalidTypeException} <p>An exception for trying to create or access sub-resource that is either invalid or not supported. Gives http status code of 409.</p>
     *   - {LimitExceededException} <p>An exception for trying to create more than allowed resources or sub-resources. Gives http status code of 409.</p>
     *   - {ResourceNotFoundException} <p>An exception for accessing or deleting a resource that does not exist. Gives http status code of 400.</p>
     *   - {ValidationException} <p>An exception for missing / invalid input fields. Gives http status code of 400.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    updateElasticsearchDomainConfig(args: UpdateElasticsearchDomainConfigInput): Promise<UpdateElasticsearchDomainConfigOutput>;
    updateElasticsearchDomainConfig(args: UpdateElasticsearchDomainConfigInput, cb: (err: any, data?: UpdateElasticsearchDomainConfigOutput) => void): void;
    /**
     * <p>Allows you to either upgrade your domain or perform an Upgrade eligibility check to a compatible Elasticsearch version.</p>
     *
     * This operation may fail with one of the following errors:
     *   - {BaseException} <p>An error occurred while processing the request.</p>
     *   - {ResourceNotFoundException} <p>An exception for accessing or deleting a resource that does not exist. Gives http status code of 400.</p>
     *   - {ResourceAlreadyExistsException} <p>An exception for creating a resource that already exists. Gives http status code of 400.</p>
     *   - {DisabledOperationException} <p>An error occured because the client wanted to access a not supported operation. Gives http status code of 409.</p>
     *   - {ValidationException} <p>An exception for missing / invalid input fields. Gives http status code of 400.</p>
     *   - {InternalException} <p>The request processing has failed because of an unknown error, exception or failure (the failure is internal to the service) . Gives http status code of 500.</p>
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    upgradeElasticsearchDomain(args: UpgradeElasticsearchDomainInput): Promise<UpgradeElasticsearchDomainOutput>;
    upgradeElasticsearchDomain(args: UpgradeElasticsearchDomainInput, cb: (err: any, data?: UpgradeElasticsearchDomainOutput) => void): void;
}
